OC.L10N.register(
    "core",
    {
    "Please select a file." : "Выберите файл.",
    "File is too big" : "Файл слишком велик",
    "The selected file is not an image." : "Выбранный файл не является изображением.",
    "The selected file cannot be read." : "Выбранный файл не может быть прочитан.",
    "The file was uploaded" : "Файл загружен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Загруженный файл превышает директиву upload_max_filesize в php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Загруженный файл превышает директиву MAX_FILE_SIZE, указанную в HTML-форме.",
    "The file was only partially uploaded" : "Файл получен частично",
    "No file was uploaded" : "Файл не получен",
    "Missing a temporary folder" : "Отсутствует временный каталог",
    "Could not write file to disk" : "Невозможно записать файл на диск",
    "A PHP extension stopped the file upload" : "Загрузка файла была прервана модулем расширений PHP",
    "Invalid file provided" : "Указан недопустимый файл",
    "No image or file provided" : "Не указано изображение или файл",
    "Unknown filetype" : "Неизвестный тип файла",
    "An error occurred. Please contact your admin." : "Произошла ошибка. Свяжитесь со своим администратором.",
    "Invalid image" : "Недопустимое изображение",
    "State token does not match" : "Токен состояния не совпадает",
    "Invalid app password" : "Неверный пароль приложения",
    "Could not complete login" : "Не удалось завершить вход в систему",
    "State token missing" : "Отсутствует токен состояния",
    "Your login token is invalid or has expired" : "Ваш токен неверен или истёк",
    "Please use original client" : "Используйте оригинальное приложение-клиент",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Используется сборка Nextcloud для сообщества. Данная сборка не поддерживается и имеет ограниченный функционал push-уведомлений.",
    "Login" : "Войти",
    "Unsupported email length (>255)" : "Неподдерживаемая длина адреса эл. почты (более 255 символов)",
    "Password reset is disabled" : "Сброс пароля отключён",
    "Could not reset password because the token is expired" : "Не удалось сбросить пароль, т.к. токен просрочен",
    "Could not reset password because the token is invalid" : "Не удалось сбросить пароль, т.к. токен не верный",
    "Password is too long. Maximum allowed length is 469 characters." : " Пароль не может быть длиннее 469 символов.",
    "%s password reset" : "Сброс пароля %s",
    "Password reset" : "Сброс пароля",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Для сброса пароля нажмите на кнопку. Если вы не запрашивали сброс пароля, просто проигнорируйте это письмо.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Для сброса пароля нажмите на ссылку. Если вы не запрашивали сброс пароля, просто проигнорируйте это письмо.",
    "Reset your password" : "Сбросить пароль",
    "The given provider is not available" : "Указанный провайдер недоступен",
    "Task not found" : "Задача не найдена",
    "Internal error" : "Внутренняя ошибка",
    "Not found" : "Не найдено",
    "Node is locked" : "Узел заблокирован",
    "Bad request" : "Неверный запрос",
    "Input text is too long" : "Введённый текст слишком длинный",
    "Requested task type does not exist" : "Запрошенный тип задачи не существует",
    "Necessary language model provider is not available" : "Необходимый поставщик языковой модели недоступен",
    "No text to image provider is available" : "Поставщик преобразования текста в изображение недоступен",
    "Image not found" : "Изображение не найдено",
    "No translation provider available" : "Поставщик услуг перевода недоступен",
    "Could not detect language" : "Не удалось определить язык",
    "Unable to translate" : "Не удается перевести",
    "No valid filters provided" : "Нет подходящих фильтров",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Шаг восстановления:",
    "Repair info:" : "Информация восстановления:",
    "Repair warning:" : "Предупреждение восстановления:",
    "Repair error:" : "Ошибка восстановления:",
    "Nextcloud Server" : "Сервер Nextcloud",
    "Some of your link shares have been removed" : "Некоторые из ваших ссылок на общие ресурсы были удалены",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Из-за ошибки в безопасности нам пришлось удалить некоторые из ваших ссылок на опубликованные файлы или папки. Перейдите по ссылке для получения дополнительной информации.",
    "The account limit of this instance is reached." : "Достигнут лимит пользователей этого экземпляра сервера.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Для увеличения лимита пользователей введите код подписки в приложении «Поддержка». Оформление подписки рекомендуется при использовании Nexcloud в бизнесе, а также позволяет получить дополнительные преимущества, предлагаемые Nextcloud для корпоративных пользователей.",
    "Learn more ↗" : "Дополнительная информация ↗",
    "Preparing update" : "Подготовка к обновлению",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Пожалуйста, используйте обновление из терминала, поскольку обновление через браузер отключено в вашем файле конфигурации config.php.",
    "Turned on maintenance mode" : "Включён режим обслуживания ",
    "Turned off maintenance mode" : "Отключён режим обслуживания",
    "Maintenance mode is kept active" : "Режим обслуживания оставлен включенным",
    "Updating database schema" : "Выполняется обновление схемы базы данных",
    "Updated database" : "База данных обновлена",
    "Update app \"%s\" from App Store" : "Выполняется обновление приложения «%s»",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных %s (может занять длительное время, зависящее от размера базы данных)",
    "Updated \"%1$s\" to %2$s" : "Приложение «%1$s» обновлено до версии %2$s",
    "Set log level to debug" : "Установлен отладочный уровень протоколирования",
    "Reset log level" : "Сброс уровня протоколирования",
    "Starting code integrity check" : "Начат процесс проверки целостности кода",
    "Finished code integrity check" : "Проверка целостности кода завершена",
    "%s (incompatible)" : "%s (несовместимое)",
    "The following apps have been disabled: %s" : "Были отключены следующие приложения: %s",
    "Already up to date" : "Не нуждается в обновлении",
    "Windows Command Script" : "Командный сценарий Windows",
    "Electronic book document" : "Электронная книга",
    "TrueType Font Collection" : "Набор шрифтов TrueType",
    "Web Open Font Format" : "Файл шрифта в формате Open Font",
    "GPX geographic data" : "Пространственные данные GPX",
    "Gzip archive" : "Архив Gzip",
    "Adobe Illustrator document" : "Файл Adode Illustrator",
    "Java source code" : "Исходный код на языке Java",
    "JavaScript source code" : "Исходный код на языке JavaScript",
    "JSON document" : "Файл в формате JSON",
    "Microsoft Access database" : "База данных Microsoft Access",
    "Microsoft OneNote document" : "Документ Microsoft OneNote",
    "Microsoft Word document" : "Документ Microsoft Word",
    "Unknown" : "Неизвестно",
    "PDF document" : "Документ в формате PDF",
    "PostScript document" : "Документ в формате PostScript",
    "RSS summary" : "RSS-сводка",
    "Android package" : "Пакет Android",
    "KML geographic data" : "Пространственные данные в формате MKL",
    "KML geographic compressed data" : "Сжатые пространственные данные в формате KML",
    "Lotus Word Pro document" : "Документ Lotus Word Pro",
    "Excel spreadsheet" : "Таблица Excel",
    "Excel add-in" : "Дополнение Excel",
    "Excel 2007 binary spreadsheet" : "Таблица в двоичном формате Excel 2007",
    "Excel spreadsheet template" : "Шаблон таблицы Excel",
    "Outlook Message" : "Сообщение Outlook",
    "PowerPoint presentation" : "Презентация Powerpoint",
    "PowerPoint add-in" : "Дополнение Powerpoint",
    "PowerPoint presentation template" : "Шаблон презентации Powerpoint",
    "Word document" : "Документ Word",
    "ODF formula" : "Формула в формате ODF",
    "ODG drawing" : "Рисунок в формате ODG",
    "ODG drawing (Flat XML)" : "Рисунок в формате ODG (простой XML)",
    "ODG template" : "Шаблон ODG",
    "ODP presentation" : "Презентация в формате ODP",
    "ODP presentation (Flat XML)" : "Презентация в формате ODP (простой XML)",
    "ODP template" : "Шаблон ODP",
    "ODS spreadsheet" : "Таблица ODS",
    "ODS spreadsheet (Flat XML)" : "Таблица ODS (плоский XML)",
    "ODS template" : "Шаблон ODS",
    "ODT document" : "Документ ODT",
    "ODT document (Flat XML)" : "Документ ODT (плоский XML)",
    "ODT template" : "Шаблон ODT",
    "PowerPoint 2007 presentation" : "Презентация PowerPoint 2007",
    "PowerPoint 2007 show" : "Демонстрация PowerPoint 2007",
    "PowerPoint 2007 presentation template" : "Шаблон презентации PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Таблица Excel 2007",
    "Excel 2007 spreadsheet template" : "Шаблон таблицы Excel 2007",
    "Word 2007 document" : "Документ Word 2007",
    "Word 2007 document template" : "Шаблон документа Word 2007",
    "Microsoft Visio document" : "Документ Microsoft Visio",
    "WordPerfect document" : "Документ WordPerfect",
    "7-zip archive" : "Архив 7-zip",
    "Blender scene" : "Сцена Blender",
    "Bzip2 archive" : "Архив Bzip2",
    "Debian package" : "Пакет Debian",
    "FictionBook document" : "Документ FictionBook",
    "Unknown font" : "Неизвестный шрифт",
    "Krita document" : "Документ Krita",
    "Mobipocket e-book" : "Электронная книга Mobipocket",
    "Windows Installer package" : "Пакет Windows Installer",
    "Perl script" : "Сценарий Perl",
    "PHP script" : "Сценарий PHP",
    "Tar archive" : "Архив tar",
    "XML document" : "Документ в формате XML",
    "YAML document" : "Документ в формате YAML",
    "Zip archive" : "Архив zip",
    "Zstandard archive" : "Архив zstandart",
    "AAC audio" : "Звуковой файл в формате AAC",
    "FLAC audio" : "Звуковой файл в формате FLAC",
    "MPEG-4 audio" : "Звуковой файл в формате MPEG-4",
    "MP3 audio" : "Звуковой файл в формате MP3",
    "Ogg audio" : "Звуковой файл в формате ogg",
    "RIFF/WAVe standard Audio" : "Стандартное аудио RIFF/WAVe",
    "WebM audio" : "Аудио WebM",
    "MP3 ShoutCast playlist" : "Плейлист MP3 ShoutCast",
    "Windows BMP image" : "Точечный рисунок Windows",
    "Better Portable Graphics image" : "Изображение Better Portable Graphics",
    "EMF image" : "Изображение в формате EMF",
    "GIF image" : "Изображение в формате GIF",
    "HEIC image" : "Изображение в формате HEIC",
    "HEIF image" : "Изображение в формате HEIF",
    "JPEG-2000 JP2 image" : "Изображение в формате JPEG-2000 JP2",
    "JPEG image" : "Изображение в формате JPEG",
    "PNG image" : "Изображение PNG",
    "SVG image" : "Изображение в формате PNG",
    "Truevision Targa image" : "Изображение в формате Truevision Targa",
    "TIFF image" : "Изображение в формате TIFF",
    "WebP image" : "Изображение в формате WebP",
    "Digital raw image" : "Файл цифрового негатива",
    "Windows Icon" : "Значок Windows",
    "Email message" : "Сообщение эл. почты",
    "VCS/ICS calendar" : "Календарь VCS/ICS",
    "CSS stylesheet" : "Таблица стилей CSS",
    "CSV document" : "Документ в формате CSV",
    "HTML document" : "Документ в формате HTML",
    "Markdown document" : "Документ в формате Markdown",
    "Org-mode file" : "Файл Org-mode",
    "Plain text document" : "Текстовый документ",
    "Rich Text document" : "Документ в формате Rich Text",
    "Electronic business card" : "Цифровая визитная карточка",
    "C++ source code" : "Исходный код на языке C++",
    "LDIF address book" : "Адресная книга в формате LDIF",
    "NFO document" : "Файл описания в формате NFO",
    "PHP source" : "Исходный код на языке PHP",
    "Python script" : "Файл сценария на языке Python",
    "ReStructuredText document" : "Документ ReStructuredText",
    "3GPP multimedia file" : "Мультимедийный файл в формате 3GPP",
    "MPEG video" : "Видеофайл в формате MPEG",
    "DV video" : "Видеофайл в формате DV",
    "MPEG-2 transport stream" : "Транспортный поток в формате MPEG-2",
    "MPEG-4 video" : "Видеофайл в формате MPEG-4",
    "Ogg video" : "Видеофайл в формате Ogg",
    "QuickTime video" : "Видеофайл в формате QuickTime",
    "WebM video" : "Видеофайл в формате WebM",
    "Flash video" : "Видеофайл в формате Flash",
    "Matroska video" : "Видеофайл в формате Matroska",
    "Windows Media video" : "Видеофайл в формате Windows Media",
    "AVI video" : "Видеофайл в формате AVI",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Выполняется обновление. Не уходите с этой страницы, т.к. в некоторых случаях может прервать процесс.",
    "Update to {version}" : "Обновление до версии {version}",
    "An error occurred." : "Произошла ошибка.",
    "Please reload the page." : "Обновите страницу.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновление не удалось. Больше информации  о данной проблеме можно найти <a href=\"{url}\">в сообщении на нашем форуме</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Обновление не удалось. Сообщите об этой проблеме <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">сообществу Nextcloud</a>.",
    "Continue to {productName}" : "Перейти к {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Обновление выполнено успешно. Перенаправление в {productName} через %n секунду.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунды.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд."],
    "Done" : "Выполненные",
    "Applications menu" : "Меню приложений",
    "Apps" : "Приложения",
    "More apps" : "Ещё приложения",
    "_{count} notification_::_{count} notifications_" : ["{count} уведомление","{count} уведомлений","{count} уведомлений","{count} уведомлений"],
    "No" : "Нет",
    "Yes" : "Да",
    "App password" : "Пароль приложения",
    "Grant access" : "Разрешить доступ",
    "The remote URL must include the user." : "Удаленный URL-адрес должен содержать имя пользователя.",
    "Invalid remote URL." : "Неверный удаленный URL-адрес.",
    "Failed to add the public link to your Nextcloud" : "Не удалось создать общедоступную ссылку",
    "Federated user" : "Федеративный пользователь",
    "user@your-nextcloud.org" : "пользователь@ваш-nextcloud.org",
    "Create share" : "Создать общий ресурс",
    "Direct link copied" : "Прямая ссылка скопирована",
    "Please copy the link manually:" : "Выполните копирование ссылки вручную:",
    "Custom date range" : "Настраиваемый диапазон дат",
    "Pick start date" : "Выберите дату начала",
    "Pick end date" : "Выберите дату окончания",
    "Search in date range" : "Поиск по диапазону дат",
    "Search in current app" : "Поиск в текущем приложении",
    "Clear search" : "Очистить поиск",
    "Search everywhere" : "Искать везде",
    "Searching …" : "Поиск …",
    "Start typing to search" : "Начните вводить символы для поиска",
    "Minimum search length is {minSearchLength} characters" : "Минимальная длина поиска - {minSearchLength} символов",
    "No matching results" : "Нет совпадающих результатов",
    "Today" : "Сегодня",
    "Last 7 days" : "Последние 7 дней",
    "Last 30 days" : "Последние 30 дней",
    "This year" : "Этот год",
    "Last year" : "Прошлый год",
    "Between {startDate} and {endDate}" : "Между {startDate} и {endDate}",
    "Unified search" : "Объединённый поиск",
    "Search apps, files, tags, messages" : "Поиск приложений, файлов, тегов, сообщений",
    "Places" : "Места",
    "Date" : "Дата",
    "Search people" : "Поиск людей",
    "People" : "Люди",
    "Filter in current view" : "Фильтр в текущем виде",
    "Search connected services" : "Поиск подключенных сервисов",
    "Results" : "Результаты",
    "Load more results" : "Загрузить дополнительные результаты",
    "Search in" : "Искать в",
    "Log in" : "Войти",
    "Logging in …" : "Вход в систему …",
    "Log in to {productName}" : "Вход в {productName}",
    "Wrong login or password." : "Неверное имя пользователя или пароль.",
    "This account is disabled" : "Эта учётная запись отключена",
    "Account name or email" : "Учётная запись или адрес эл. почты",
    "Account name" : "Имя учётной записи",
    "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
    "Please contact your administrator." : "Обратитесь к своему администратору.",
    "Session error" : "Ошибка сеанса",
    "It appears your session token has expired, please refresh the page and try again." : "Похоже, токен вашей сессии истёк. Пожалуйста, обновите страницу и попробуйте снова.",
    "An internal error occurred." : "Произошла внутренняя ошибка.",
    "Please try again or contact your administrator." : "Попробуйте ещё раз или свяжитесь со своим администратором",
    "Password" : "Пароль",
    "Remember me" : "Запомнить меня",
    "Log in with a device" : "Войти с устройства",
    "Login or email" : "Имя пользователя или адрес эл. почты",
    "Your account is not setup for passwordless login." : "Ваша учётная запись не настроена на вход без пароля.",
    "Your connection is not secure" : "Соединение установлено с использованием небезопасного протокола",
    "Passwordless authentication is only available over a secure connection." : "Вход без пароля возможет только через защищённое соединение",
    "Browser not supported" : "Используемый браузер не поддерживается",
    "Passwordless authentication is not supported in your browser." : "Ваш браузер не поддерживает безпарольную аутентификацию",
    "Reset password" : "Сбросить пароль",
    "Back to login" : "Вернуться на страницу входа",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Если эта учётная запись существует, на ее адрес электронной почты было отправлено сообщение о сбросе пароля. Если вы его не получили, подтвердите свой адрес электронной почты и/или имя учетной записи, проверьте папки со спамом/нежелательной почтой или обратитесь за помощью к своему системному администратору.",
    "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Свяжитесь со своим администратором.",
    "Password cannot be changed. Please contact your administrator." : "Пароль не может быть изменён. Свяжитесь со своим системным администратором.",
    "New password" : "Новый пароль",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваши файлы хранятся в зашифрованном виде. После сброса пароля будет невозможно получить доступ к этим данным. Если вы не уверены, что делать дальше — обратитесь к своему системному администратору. Продолжить?",
    "I know what I'm doing" : "Я понимаю, что делаю",
    "Resetting password" : "Сброс пароля",
    "Schedule work & meetings, synced with all your devices." : "Составляйте графики работы и встреч, синхронизированные со всеми своими устройствами.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Храните информацию о своих коллегах и друзьях в одном месте без утечки их личных данных.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Простое приложение электронной почты, прекрасно интегрированное с приложениями Файлы, Контакты и Календарь.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Общение в чате, видеозвонки, демонстрация экрана, онлайн-встречи и веб-конференции - в вашем браузере и на мобильных устройствах.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Совместная работа с документами, таблицами и презентациями, основанная на Collabora Online.",
    "Distraction free note taking app." : "Простые приложение для ведения заметок.",
    "Recommended apps" : "Рекомендованные приложения",
    "Loading apps …" : "Загрузка приложений …",
    "Could not fetch list of apps from the App Store." : "Не удалось получить список приложений.",
    "App download or installation failed" : "Не удалось скачать или установить приложение",
    "Cannot install this app because it is not compatible" : "Приложение не может быть установлено, так как оно несовместимо",
    "Cannot install this app" : "Это приложение не может быть установлено",
    "Skip" : "Пропустить",
    "Installing apps …" : "Установка приложений …",
    "Install recommended apps" : "Установить рекомендуемые приложения",
    "Online" : "В сети",
    "Away" : "Неактивен",
    "Busy" : "Занят",
    "Do not disturb" : "Не беспокоить",
    "Mute all notifications" : "Без уведомлений",
    "Invisible" : "Невидимый",
    "Appear offline" : "\"Не в сети\" для остальных",
    "Avatar of {displayName}" : "Изображение профиля {displayName}",
    "Settings menu" : "Меню настроек",
    "Loading your contacts …" : "Загрузка контактов …",
    "Looking for {term} …" : "Поиск {term} …",
    "Search contacts" : "Поиск контактов",
    "Reset search" : "Очистить поиск",
    "Search contacts …" : "Поиск контактов …",
    "Could not load your contacts" : "Ошибка получения контактов",
    "No contacts found" : "Контактов не найдено",
    "Show all contacts" : "Показать все контакты",
    "Install the Contacts app" : "Установить приложение Контакты",
    "Search" : "Найти",
    "No results for {query}" : "По запросу «{query}» ничего не найдено",
    "Press Enter to start searching" : "Нажмите Enter, чтобы начать поиск",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Чтобы начать поиск необходимо ввести как минимум  {minSearchLength} символ","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символа","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символов","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символа"],
    "An error occurred while searching for {type}" : "Произошла ошибка при поиске {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Поиск начнётся при наборе текста. Для перехода к результатам поиска используйте клавиши со стрелками.",
    "Search for {name} only" : "Искать только для «{name}»",
    "Loading more results …" : "Загрузка дополнительных результатов …",
    "Forgot password?" : "Забыли пароль?",
    "Back to login form" : "Вернуться к форме входа",
    "Back" : "Назад",
    "Login form is disabled." : "Форма входа отключена.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Диалог входа отключен. Используйте другой способ входа или свяжитесь с администратором.",
    "Connect to your account" : "Вход в систему",
    "Security warning" : "Предупреждение безопасности",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Если вы не пытались настроить новое устройство или приложение, значит, кто-то пытается получить доступ к вашим данным. В этом случае свяжитесь с администратором системы.",
    "Alternative log in using app password" : "Другой способ входа с использованием пароля приложения",
    "Account connected" : "Аккаунт подключен",
    "Your client should now be connected!" : "Приложение-клиент подключено.",
    "You can close this window." : "Можете закрыть это окно.",
    "Account access" : "Доступ к аккаунту",
    "More actions" : "Больше действий",
    "User menu" : "Меню пользователя",
    "Your guest name: {user}" : "Ваше гостевое имя: {user}",
    "You are currently not identified." : "В данный момент вы не идентифицированы.",
    "Set public name" : "Задать публичное имя",
    "Change public name" : "Изменить публичное имя",
    "Password is too weak" : "Пароль слишком слабый",
    "Password is weak" : "Пароль слабый",
    "Password is average" : "Пароль средний",
    "Password is strong" : "Пароль надежный",
    "Password is very strong" : "Пароль очень надежный",
    "Password is extremely strong" : "Пароль очень надежный",
    "Unknown password strength" : "Неизвестная надежность пароля",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш каталог данных и файлы, вероятно, доступны из Интернета, поскольку файл <code>.htaccess</code> не работает.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Информацию о том, как правильно настроить сервер,{linkStart} смотрите в документации.{linkEnd}",
    "Autoconfig file detected" : "Обнаружен файл автоконфигурации",
    "The setup form below is pre-filled with the values from the config file." : "Форма настройки ниже, предварительно заполнена значениями из файла конфигурации.",
    "Create administration account" : "Создать учетную запись администратора",
    "Administration account name" : "Имя учетной записи администратора",
    "Administration account password" : "Пароль учетной записи администратора",
    "Storage & database" : "Хранилище и база данных",
    "Data folder" : "Каталог с данными",
    "Database configuration" : "Конфигурация базы данных",
    "Database type" : "Тип базы данных",
    "Only {firstAndOnlyDatabase} is available." : "Только {firstAndOnlyDatabase} доступно.",
    "Install and activate additional PHP modules to choose other database types." : "Установите и активируйте дополнительные модули PHP для возможности выбора других типов баз данных.",
    "For more details check out the documentation." : "За дополнительными сведениями обратитесь к документации.",
    "Performance warning" : "Предупреждение о производительности",
    "You chose SQLite as database." : "Вы выбрали SQLite в качестве базы данных.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite следует использовать только для минимальных и разрабатываемых экземпляров. Для производства мы рекомендуем другую базу данных.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Настоятельно не рекомендуется использовать механизм баз данных SQLite при использовании синхронизации файлов с использованием приложений-клиентов.",
    "Database connection" : "Соединение с базой данных",
    "Database user" : "Пользователь базы данных",
    "Database password" : "Пароль базы данных",
    "Database name" : "Имя базы данных",
    "Database tablespace" : "Табличное пространство базы данных",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Пожалуйста укажите номер порта вместе с именем хоста (напр. localhost:5432)",
    "Database host" : "Хост базы данных",
    "localhost" : "локальный хост",
    "Installing …" : "Установка …",
    "Install" : "Установить",
    "Need help?" : "Требуется помощь?",
    "See the documentation" : "Посмотреть документацию",
    "{name} version {version} and above" : "{name} версии {version} и новее",
    "This browser is not supported" : "Используемый браузер не поддерживается",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Используемый браузер не поддерживается. Обновитесь до более новой версии или используйте другой браузер.",
    "Continue with this unsupported browser" : "Продолжить с использованием неподдерживаемого браузера",
    "Supported versions" : "Поддерживаемые версии",
    "Search {types} …" : "Поиск {types} …",
    "Choose {file}" : "Выбран «{file}»",
    "Choose" : "Выбрать",
    "Copy to {target}" : "Скопировать в {target}",
    "Copy" : "Копировать",
    "Move to {target}" : "Переместить в «{target}»",
    "Move" : "Переместить",
    "OK" : "ОК",
    "read-only" : "только для чтения",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файлах в состоянии конфликта","{count} файла в состоянии конфликта","{count} файлов в состоянии конфликта","{count} файлов в состоянии конфликта"],
    "One file conflict" : "Один файл в состоянии конфликта",
    "New Files" : "Новые файлы",
    "Already existing files" : "Существующие файлы",
    "Which files do you want to keep?" : "Какие файлы вы хотите сохранить?",
    "If you select both versions, the copied file will have a number added to its name." : "При выборе обеих версий к названию копируемого файла будет добавлена цифра",
    "Cancel" : "Отмена",
    "Continue" : "Продолжить",
    "(all selected)" : "(все выбранные)",
    "({count} selected)" : "(выбрано: {count})",
    "Error loading file exists template" : "Ошибка при загрузке шаблона существующего файла",
    "Saving …" : "Сохранение…",
    "Groups" : "Группы",
    "Group list is empty" : "Список групп пуст",
    "Unable to retrieve the group list" : "Не удалось получить список групп",
    "seconds ago" : "только что",
    "Connection to server lost" : "Потеряно подключение к серверу",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Возникла проблема при загрузке страницы, повторная попытка через %n секунду","Возникла проблема при загрузке страницы, повторная попытка через %n секунды","Возникла проблема при загрузке страницы, повторная попытка через %n секунд","Возникла проблема при загрузке страницы, повторная попытка через %n секунд"],
    "Add to a project" : "Добавить к проекту",
    "Show details" : "Подробные сведения",
    "Hide details" : "Скрыть подробные сведения",
    "Rename project" : "Переименовать проект",
    "Failed to rename the project" : "Не удалось переименовать проект",
    "Failed to create a project" : "Не удалось создать проект",
    "Failed to add the item to the project" : "Не удалось добавить элемент к проекту",
    "Connect items to a project to make them easier to find" : "Добавьте объекты в проект, чтобы их было легче найти",
    "Type to search for existing projects" : "Нажмите, чтобы найти существующий проект",
    "New in" : "Новые возможности",
    "View changelog" : "Просмотреть изменения",
    "Close \"{dialogTitle}\" dialog" : "Закрыть «{dialogTitle}»",
    "Email length is at max (255)" : "Максимальная длина адреса эл. почты (255 символов)",
    "Clipboard not available, please copy manually" : "Буфер обмена недоступен, пожалуйста, скопируйте вручную",
    "Personal" : "Личное",
    "Accounts" : "Учётные записи",
    "Admin" : "Администрирование",
    "Help" : "Помощь",
    "Access forbidden" : "Доступ запрещён",
    "You are not allowed to access this page." : "Вам не разрешен доступ к этой странице.",
    "Back to %s" : "Вернуться к %s",
    "Page not found" : "Страница не найдена",
    "The page could not be found on the server or you may not be allowed to view it." : "Страница не найдена на сервере, или у вас нет прав на ее просмотр.",
    "Too many requests" : "Превышено количество запросов",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Превышено количество запросов из вашей сети. Попробуйте позднее или сообщите администратору об этой ошибке.",
    "Error" : "Ошибка",
    "Internal Server Error" : "Внутренняя ошибка сервера",
    "The server was unable to complete your request." : "Запрос не может быть обработан сервером.",
    "If this happens again, please send the technical details below to the server administrator." : "Если это случится ещё раз, отправьте администратору сервера подробное сообщение о произошедшем, приведённое ниже.",
    "More details can be found in the server log." : "Подробную информацию можно найти в журнале сервера.",
    "For more details see the documentation ↗." : "Для получения более подробной информации ознакомьтесь с документацией ↗.",
    "Technical details" : "Технические подробности",
    "Remote Address: %s" : "Удаленный адрес: %s",
    "Request ID: %s" : "ID Запроса: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Сообщение: %s",
    "File: %s" : "Файл: «%s»",
    "Line: %s" : "Строка: %s",
    "Trace" : "Трассировка",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Похоже, вы пытаетесь переустановить Nextcloud. Однако файл «CAN_INSTALL» отсутствует в вашем каталоге конфигурации. Чтобы продолжить создайте файл «CAN_INSTALL» в каталоге конфигурации.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не удалось удалить «CAN_INSTALL» из каталога конфигурации. Удалите этот файл вручную.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Для корректной работы приложения требуется JavaScript.  {linkstart}Включите JavaScript{linkend} и обновите страницу.",
    "Skip to main content" : "Перейти к основному содержанию",
    "Skip to navigation of app" : "Перейти к навигации по приложению",
    "Go to %s" : "Перейти к %s",
    "Get your own free account" : "Создайте свою бесплатную учётную запись",
    "Previous" : "Предыдущий",
    "This share is password-protected" : "Доступ к этому ресурсу защищён паролем",
    "The password is wrong or expired. Please try again or request a new one." : "Введённый пароль неверен или срок его действия истёк. Попробуйте снова ввести его или запросите новый пароль.",
    "Please type in your email address to request a temporary password" : "Введите свой адрес эл. почты для запроса временного пароля",
    "Email address" : "Адрес эл. почты",
    "Password sent!" : "Пароль отправлен",
    "You are not authorized to request a password for this share" : "У вас недостаточно прав для запроса пароля для доступа к этому общему ресурсу",
    "Two-factor authentication" : "Двухфакторная аутентификация",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повышенная безопасность включена для вашей учетной записи. Выберете второй фактор для подтверждения подлинности пользователя.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Не удалось использовать хотя бы один из двух настроенных способов двуфакторной аутентификации. Обратитесь к администратору.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двухфакторная аутентификация включена но не сконфигурирована для вашей учетной записи. Обратитесь к администратору сервера для консультации. ",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двухфакторная аутентификация включена но не сконфигурирована для вашей учетной записи. Пожалуйста, продолжите, чтобы установить двухфакторную аутентификацию.",
    "Set up two-factor authentication" : "Установить двухфакторную аутентификацию",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двухфакторная аутентификация включена в настройках, но ваша учётная запись еще не сконфигурирована для его использования. Используйте один из резервных кодов для входа в аккаунт или свяжитесь с вашим администратором для получения помощи.",
    "Use backup code" : "Использовать резервный код",
    "Cancel login" : "Отменить вход",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Повышенная безопасность включена для вашей учетной записи. Выберите провайдера для настройки:",
    "Error while validating your second factor" : "Ошибка проверки кода",
    "Access through untrusted domain" : "Доступ через недоверенный домен",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Обратитесь к администратору. Если вы являетесь администратором этого сервера, отредактируйте параметр «trusted_domains» в файле «config/config.php». Пример настройки можно найти в файле «config/config.sample.php».",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Дополнительная информация как это настроить может быть найдена в %1$sдокументации %2$s",
    "App update required" : "Требуется обновление приложения",
    "%1$s will be updated to version %2$s" : "%1$s будет обновлено до версии %2$s",
    "The following apps will be updated:" : "Следующие приложения будут обновлены:",
    "These incompatible apps will be disabled:" : "Эти несовместимые приложения будут отключены:",
    "The theme %s has been disabled." : "Тема %s была отключена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продолжением убедитесь, что вы сделали резервную копию базы данных, каталога конфигурации и каталога с данными.",
    "Start update" : "Запустить обновление",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать тайм-аутов в крупных установках, вместо этого можно выполнить следующую команду в каталоге установки:",
    "Detailed logs" : "Подробные журналы",
    "Update needed" : "Требуется обновление",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Используйте инструмент командной строки для выполнения обновления, так как в этом развёртывании создано более 50 пользователей. ",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Для получения помощи обратитесь к <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документации</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, что в случае продолжения обновления через веб-интерфейс возникает риск тайм-аута запроса, который может привести к потере данных. У меня есть резервная копия, и я знаю, как восстановить систему в случае сбоя.",
    "Upgrade via web on my own risk" : "Обновить используя веб-интерфейс на мой страх и риск",
    "Maintenance mode" : "Режим обслуживания",
    "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
    "This page will refresh itself when the instance is available again." : "Эта страница обновится автоматически когда сервер снова станет доступен.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
    "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
    "For more details see the {linkstart}documentation ↗{linkend}." : "За дополнительными сведениями обратитесь к {linkstart}документации ↗{linkend}.",
    "unknown text" : "неизвестный текст",
    "Hello world!" : "Привет мир!",
    "sunny" : "солнечно",
    "Hello {name}, the weather is {weather}" : "Здравствуйте, {name}! Погода сейчас  {weather}",
    "Hello {name}" : "Здравствуйте, {name}!",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Эти результаты поиска<script>alert(1)</script></strong>",
    "new" : "новый",
    "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файла"],
    "Direct link copied to clipboard" : "Прямая ссылка, скопированная в буфер обмена",
    "Searching …" : "Поиск…",
    "Logging in …" : "Вход в систему…",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "С вашего IP-адреса было выполнено множество неудачных попыток входа в систему. Следующую попытку можно будет выполнить через 30 секунд.",
    "Loading apps …" : "Получение списка приложений…",
    "Installing apps …" : "Установка приложений…",
    "Loading your contacts …" : "Загрузка контактов…",
    "Looking for {term} …" : "Поиск {term}…",
    "Search contacts …" : "Поиск контакта…",
    "Loading more results …" : "Загрузка дополнительных результатов…",
    "Search {types} …" : "Поиск {types}…",
    "Saving …" : "Сохранение…",
    "Very weak password" : "Очень слабый пароль",
    "Weak password" : "Слабый пароль",
    "So-so password" : "Так себе пароль",
    "Good password" : "Хороший пароль",
    "Strong password" : "Надёжный пароль",
    "No action available" : "Нет доступных действий",
    "Error fetching contact actions" : "Ошибка получения действий контакта",
    "Non-existing tag #{tag}" : "Несуществующая метка #{tag}",
    "Restricted" : "Ограниченный",
    "Delete" : "Удалить",
    "Rename" : "Переименовать",
    "Collaborative tags" : "Совместные теги",
    "No tags found" : "Метки не найдены",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются. Возможно, каталог данных и файлы свободно доступны из интернета.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Сведения о правильной настройке сервера можно найти в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документации</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Создайте учетную запись администратора</strong>",
    "New admin account name" : "Новое имя учетной записи администратора",
    "New admin password" : "Новый пароль администратора",
    "Show password" : "Показать пароль",
    "Toggle password visibility" : "Переключить видимость пароля",
    "Configure the database" : "Настройка базы данных",
    "Only %s is available." : "Доступен только %s.",
    "Database account" : "Учётная запись базы данных",
    "Installing …" : "Установка ...",
    "Please log in before granting %1$s access to your %2$s account." : "Для предоставления %1$s доступа к учётной записи %2$s необходимо войти в систему.",
    "Currently logged in as %1$s (%2$s)." : "Вход в систему выполнен под именем %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Вы собираетесь разрешить приложению %1$s доступ к своей учётной записи %2$s."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
